RuntimeEvent

Enum RuntimeEvent 

pub enum RuntimeEvent {
    RevisionBumped {
        revision: Revision,
    },
    RevisionSet {
        revision: Revision,
    },
    InputSet {
        revision: Revision,
        kind: QueryKindId,
        key_hash: u64,
        key: Key,
    },
    InputRemoved {
        revision: Revision,
        kind: QueryKindId,
        key_hash: u64,
        key: Key,
    },
    QueryInvalidated {
        revision: Revision,
        kind: QueryKindId,
        key_hash: u64,
        key: Key,
        by_kind: QueryKindId,
        by_key_hash: u64,
        by_key: Key,
    },
    QueryChanged {
        revision: Revision,
        kind: QueryKindId,
        key_hash: u64,
        key: Key,
    },
}
Notifications emitted by a Runtime.

Variants



RevisionBumped

The global revision counter was bumped.

Fields

revision: Revision

New revision value.



RevisionSet

The global revision counter was set directly (usually after cache load).

Fields

revision: Revision

New revision value.



InputSet

An input value was set.

Fields

revision: Revision

Revision at which the input was set.

kind: QueryKindId

Kind id of the input ingredient.

key_hash: u64

Stable hash of the encoded key bytes (for diagnostics).

key: Key

Postcard-encoded key bytes.



InputRemoved

An input value was removed.

Fields

revision: Revision

Revision at which the input was removed.

kind: QueryKindId

Kind id of the input ingredient.

key_hash: u64

Stable hash of the encoded key bytes (for diagnostics).

key: Key

Postcard-encoded key bytes.



QueryInvalidated

A derived query was invalidated by an input change.

Fields

revision: Revision

Revision at which invalidation happened.

kind: QueryKindId

Kind id of the invalidated query.

key_hash: u64

Stable hash of the invalidated key bytes (for diagnostics).

key: Key

Postcard-encoded key bytes for the invalidated query.

by_kind: QueryKindId

Kind id of the root input that caused invalidation.

by_key_hash: u64

Stable hash of the root input key bytes (for diagnostics).

by_key: Key

Postcard-encoded key bytes for the root input key.



QueryChanged

A derived query’s output changed at revision.

Fields

revision: Revision

Revision at which the query changed.

kind: QueryKindId

Kind id of the changed query.

key_hash: u64

Stable hash of the changed key bytes (for diagnostics).

key: Key

Postcard-encoded key bytes for the changed query.